@@ -25,7 +25,7 @@ email                : mte@users.sourceforge.net
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 #include <tqfile.h>
 #include <tqmap.h>
 #include <tqobject.h>
@@ -34,7 +34,7 @@ email                : mte@users.sourceforge.net
 #include <tqdatetime.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 #ifndef _GNCFILEANON
   #include <tdelocale.h>
   #include <tdeconfig.h>
@@ -1429,7 +1429,7 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
   MyMoneyMoney splitValue (convBadValue (gsp->value()));
   if (gsp->value() == "-1/0") { // treat gnc invalid value as zero
    // it's not quite a consistency check, but easier to treat it as such
-   postMessage ("CC", 4, splitAccount.name().latin1(), TQString(m_txDatePosted.toString(Qt::ISODate)).latin1());
+   postMessage ("CC", 4, splitAccount.name().latin1(), TQString(m_txDatePosted.toString(TQt::ISODate)).latin1());
   }
   MyMoneyMoney splitQuantity(convBadValue(gsp->qty()));
   split.setValue (splitValue);
@@ -1470,7 +1470,7 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
           e.setTradingCurrency (m_txCommodity);
           if (gncdebug) tqDebug(TQString("added price for %1, %2 date %3").
               arg(e.name()).arg(newPrice.toString()).
-              arg(m_txDatePosted.toString(Qt::ISODate)));
+              arg(m_txDatePosted.toString(TQt::ISODate)));
           m_storage->modifySecurity(e);
           MyMoneyPrice dealPrice (e.id(), m_txCommodity, m_txDatePosted, newPrice, i18n("Imported Transaction"));
           m_storage->addPrice (dealPrice);
@@ -1788,7 +1788,7 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
     } else {
       const GncRecurrence *gre = gsc->m_vpRecurrence.first();
       //tqDebug (TQString("Sched %1, pt %2, mu %3, sd %4").arg(gsc->name()).arg(gre->periodType())
-       // .arg(gre->mult()).arg(gre->startDate().toString(Qt::ISODate)));
+       // .arg(gre->mult()).arg(gre->startDate().toString(TQt::ISODate)));
       frequency = gre->getFrequency();
       schedEnabled = gsc->enabled();
     }
