@@ -19,14 +19,19 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Headers
+// TQt Headers
 
 #include <tqfile.h>
 #include <tqtextstream.h>
 
 // ----------------------------------------------------------------------------
-// KDE Headers
+// TDE Headers
 
 #include <tdelocale.h>
 #include <tdemessagebox.h>
