@@ -63,9 +63,9 @@ KChooseImportExportDlg::KChooseImportExportDlg(int type, TQWidget *parent, const
   slotTypeActivated(m_lastType);
   typeCombo->setCurrentItem(((m_lastType=="QIF") ? 0 : 1));
 
-  connect(typeCombo, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(slotTypeActivated(const TQString&)));
-  connect(okButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(accept()));
-  connect(cancelButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(reject()));
+  connect(typeCombo, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotTypeActivated(const TQString&)));
+  connect(okButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(accept()));
+  connect(cancelButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(reject()));
 }
 
 KChooseImportExportDlg::~KChooseImportExportDlg()
