@@ -20,7 +20,7 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqfile.h>
 #include <tqtextstream.h>
@@ -29,7 +29,7 @@
 #include <tqdatetimeedit.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <kgenericfactory.h>
 #include <kdebug.h>
@@ -65,7 +65,7 @@ OfxImporterPlugin::~OfxImporterPlugin()
 
 void OfxImporterPlugin::createActions(void)
 {
-  new TDEAction(i18n("OFX..."), "", 0, this, TQT_SLOT(slotImportFile()), actionCollection(), "file_import_ofx");
+  new TDEAction(i18n("OFX..."), "", 0, this, TQ_SLOT(slotImportFile()), actionCollection(), "file_import_ofx");
 }
 
 void OfxImporterPlugin::slotImportFile(void)
@@ -184,13 +184,13 @@ int OfxImporterPlugin::ofxTransactionCallback(struct OfxTransactionData data, vo
   if(data.date_posted_valid==true)
   {
     TQDateTime dt;
-    dt.setTime_t(data.date_posted, Qt::UTC);
+    dt.setTime_t(data.date_posted, TQt::UTC);
     t.m_datePosted = dt.date();
   }
   else if(data.date_initiated_valid==true)
   {
     TQDateTime dt;
-    dt.setTime_t(data.date_initiated, Qt::UTC);
+    dt.setTime_t(data.date_initiated, TQt::UTC);
     t.m_datePosted = dt.date();
   }
 
@@ -414,14 +414,14 @@ int OfxImporterPlugin::ofxStatementCallback(struct OfxStatementData data, void*
   if(data.date_start_valid==true)
   {
     TQDateTime dt;
-    dt.setTime_t(data.date_start, Qt::UTC);
+    dt.setTime_t(data.date_start, TQt::UTC);
     s.m_dateBegin = dt.date();
   }
 
   if(data.date_end_valid==true)
   {
     TQDateTime dt;
-    dt.setTime_t(data.date_end, Qt::UTC);
+    dt.setTime_t(data.date_end, TQt::UTC);
     s.m_dateEnd = dt.date();
   }
 
@@ -633,8 +633,8 @@ bool OfxImporterPlugin::updateAccount(const MyMoneyAccount& acc, bool moreAccoun
       m_preferName = acc.onlineBankingSettings().value("kmmofx-preferName").toInt() != 0;
       KOfxDirectConnectDlg dlg(acc);
 
-      connect(&dlg, TQT_SIGNAL(statementReady(const TQString&)),
-              this, TQT_SLOT(slotImportFile(const TQString&)));
+      connect(&dlg, TQ_SIGNAL(statementReady(const TQString&)),
+              this, TQ_SLOT(slotImportFile(const TQString&)));
 
       dlg.init();
       dlg.exec();
