@@ -25,7 +25,7 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqdrawutil.h>
 #include <tqpainter.h>
@@ -33,7 +33,7 @@
 #include <tqapplication.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -50,8 +50,8 @@ KMyMoneyAccountCombo::KMyMoneyAccountCombo( TQWidget* parent, const char* name )
 #ifndef KMM_DESIGNER
   m_completion = new kMyMoneyAccountCompletion(this);
 
-  connect(this, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotButtonPressed()));
-  connect(m_completion, TQT_SIGNAL(itemSelected(const TQString&)), this, TQT_SLOT(slotSelected(const TQString&)));
+  connect(this, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotButtonPressed()));
+  connect(m_completion, TQ_SIGNAL(itemSelected(const TQString&)), this, TQ_SLOT(slotSelected(const TQString&)));
 #endif
 
   // make sure that we can display a minimum of characters
@@ -165,7 +165,7 @@ void KMyMoneyAccountCombo::keyPressEvent(TQKeyEvent* k)
 
 void KMyMoneyAccountCombo::mousePressEvent(TQMouseEvent *e)
 {
-  if ( e->button() != Qt::LeftButton ) {
+  if ( e->button() != TQt::LeftButton ) {
     e->ignore();
     return;
   }
@@ -178,7 +178,7 @@ void KMyMoneyAccountCombo::mousePressEvent(TQMouseEvent *e)
 
 void KMyMoneyAccountCombo::mouseReleaseEvent(TQMouseEvent *e)
 {
-  if ( e->button() != Qt::LeftButton ) {
+  if ( e->button() != TQt::LeftButton ) {
       e->ignore();
       return;
   }
