@@ -15,8 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqpoint.h>
 #include <tqevent.h>
@@ -29,7 +33,7 @@
 #include <tqstyle.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdemessagebox.h>
 #include <tdelocale.h>
@@ -80,14 +84,14 @@ KMyMoneyAccountTreeBase::KMyMoneyAccountTreeBase(TQWidget* parent, const char* n
   m_baseCurrency.setSmallestAccountFraction(100);
   m_baseCurrency.setSmallestCashFraction(100);
 
-  connect(this, TQT_SIGNAL(dropped(TQDropEvent*,TQListViewItem*,TQListViewItem*)), this, TQT_SLOT(slotObjectDropped(TQDropEvent*,TQListViewItem*,TQListViewItem*)));
-  connect(this, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this, TQT_SLOT(slotSelectObject(TQListViewItem*)));
-  connect(this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem* , const TQPoint&)), this, TQT_SLOT(slotOpenContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
-  connect(this, TQT_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&,int)), this, TQT_SLOT(slotOpenObject(TQListViewItem*)));
+  connect(this, TQ_SIGNAL(dropped(TQDropEvent*,TQListViewItem*,TQListViewItem*)), this, TQ_SLOT(slotObjectDropped(TQDropEvent*,TQListViewItem*,TQListViewItem*)));
+  connect(this, TQ_SIGNAL(selectionChanged(TQListViewItem*)), this, TQ_SLOT(slotSelectObject(TQListViewItem*)));
+  connect(this, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem* , const TQPoint&)), this, TQ_SLOT(slotOpenContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
+  connect(this, TQ_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&,int)), this, TQ_SLOT(slotOpenObject(TQListViewItem*)));
 
   // drag and drop timer connections
-  connect( &m_autoopenTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotOpenFolder() ) );
-  connect( &m_autoscrollTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotAutoScroll() ) );
+  connect( &m_autoopenTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotOpenFolder() ) );
+  connect( &m_autoscrollTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAutoScroll() ) );
 
 }
 
@@ -129,8 +133,8 @@ void KMyMoneyAccountTreeBase::showValue(void)
 void KMyMoneyAccountTreeBase::connectNotify(const char * /* s */)
 {
   // update drag and drop settings
-  m_accountConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
-  m_institutionConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
+  m_accountConnections = (receivers(TQ_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
+  m_institutionConnections = (receivers(TQ_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
   setDragEnabled(m_accountConnections | m_institutionConnections);
   setAcceptDrops(m_accountConnections | m_institutionConnections);
 }
@@ -138,8 +142,8 @@ void KMyMoneyAccountTreeBase::connectNotify(const char * /* s */)
 void KMyMoneyAccountTreeBase::disconnectNotify(const char * /* s */)
 {
   // update drag and drop settings
-  m_accountConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
-  m_institutionConnections = (receivers(TQT_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
+  m_accountConnections = (receivers(TQ_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&))) != 0);
+  m_institutionConnections = (receivers(TQ_SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&))) != 0);
   setDragEnabled(m_accountConnections | m_institutionConnections);
   setAcceptDrops(m_accountConnections | m_institutionConnections);
 }
@@ -514,7 +518,7 @@ void KMyMoneyAccountTreeBase::viewportPaintEvent(TQPaintEvent* e)
     TQPainter painter(viewport());
 
     // This is where we actually draw the drop-highlighter
-    style().tqdrawPrimitive(TQStyle::PE_FocusRect, &painter, m_lastDropHighlighter, colorGroup(),
+    style().drawPrimitive(TQStyle::PE_FocusRect, &painter, m_lastDropHighlighter, colorGroup(),
                           TQStyle::Style_FocusAtBorder);
   }
 }
@@ -792,7 +796,7 @@ void KMyMoneyAccountTreeBase::queueSort(void)
 {
   if (sortColumn() == balanceColumn() || sortColumn() == valueColumn()) {
     ++m_queuedSort;
-    TQTimer::singleShot(100, this, TQT_SLOT(slotActivateSort()));
+    TQTimer::singleShot(100, this, TQ_SLOT(slotActivateSort()));
   }
 }
 
