@@ -19,13 +19,13 @@
 #define KMYMONEYCATEGORY_H
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 class TQWidget;
 class TQFrame;
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <kcombobox.h>
 class KPushButton;
@@ -57,7 +57,7 @@ class kMyMoneyAccountSelector;
   */
 class KMyMoneyCategory : public KMyMoneyCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
@@ -176,7 +176,7 @@ private:
 
 class KMyMoneySecurity : public KMyMoneyCategory
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneySecurity(TQWidget* parent = 0, const char* name = 0);
