@@ -15,8 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlayout.h>
 #include <tqheader.h>
@@ -25,7 +29,7 @@
 #include <tqregexp.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -67,7 +71,7 @@ KMyMoneySelector::KMyMoneySelector(TQWidget *parent, const char *name, TQWidget:
   m_selMode = TQListView::Multi;
   setSelectionMode(TQListView::Single);
 
-  connect(m_listView, TQT_SIGNAL(rightButtonPressed(TQListViewItem* , const TQPoint&, int)), this, TQT_SLOT(slotListRightMouse(TQListViewItem*, const TQPoint&, int)));
+  connect(m_listView, TQ_SIGNAL(rightButtonPressed(TQListViewItem* , const TQPoint&, int)), this, TQ_SLOT(slotListRightMouse(TQListViewItem*, const TQPoint&, int)));
 }
 
 KMyMoneySelector::~KMyMoneySelector()
@@ -89,11 +93,11 @@ void KMyMoneySelector::setSelectionMode(const TQListView::SelectionMode mode)
     // make sure, it's either Multi or Single
     if(mode != TQListView::Multi) {
       m_selMode = TQListView::Single;
-      connect(m_listView, TQT_SIGNAL(selectionChanged(void)), this, TQT_SIGNAL(stateChanged(void)));
-      connect(m_listView, TQT_SIGNAL(executed(TQListViewItem*)), this, TQT_SLOT(slotItemSelected(TQListViewItem*)));
+      connect(m_listView, TQ_SIGNAL(selectionChanged(void)), this, TQ_SIGNAL(stateChanged(void)));
+      connect(m_listView, TQ_SIGNAL(executed(TQListViewItem*)), this, TQ_SLOT(slotItemSelected(TQListViewItem*)));
     } else {
-      disconnect(m_listView, TQT_SIGNAL(selectionChanged(void)), this, TQT_SIGNAL(stateChanged(void)));
-      disconnect(m_listView, TQT_SIGNAL(executed(TQListViewItem*)), this, TQT_SLOT(slotItemSelected(TQListViewItem*)));
+      disconnect(m_listView, TQ_SIGNAL(selectionChanged(void)), this, TQ_SIGNAL(stateChanged(void)));
+      disconnect(m_listView, TQ_SIGNAL(executed(TQListViewItem*)), this, TQ_SLOT(slotItemSelected(TQListViewItem*)));
     }
   }
   TQWidget::update();
@@ -133,7 +137,7 @@ TQListViewItem* KMyMoneySelector::newTopItem(const TQString& name, const TQStrin
 
   if(m_selMode == TQListView::Multi) {
     KMyMoneyCheckListItem* q = new KMyMoneyCheckListItem(m_listView, name, key, id);
-    connect(q, TQT_SIGNAL(stateChanged(bool)), this, TQT_SIGNAL(stateChanged(void)));
+    connect(q, TQ_SIGNAL(stateChanged(bool)), this, TQ_SIGNAL(stateChanged(void)));
     p = static_cast<TQListViewItem*> (q);
 
   } else {
@@ -150,7 +154,7 @@ TQListViewItem* KMyMoneySelector::newItem(TQListViewItem* parent, const TQString
 
   if(m_selMode == TQListView::Multi) {
     KMyMoneyCheckListItem* q = new KMyMoneyCheckListItem(parent, name, key, id);
-    connect(q, TQT_SIGNAL(stateChanged(bool)), this, TQT_SIGNAL(stateChanged(void)));
+    connect(q, TQ_SIGNAL(stateChanged(bool)), this, TQ_SIGNAL(stateChanged(void)));
     p = static_cast<TQListViewItem*> (q);
 
   } else {
@@ -507,7 +511,7 @@ void KMyMoneySelector::ensureItemVisible(const TQListViewItem *it_v)
   // the slot slotShowSelected.  (ipwizard, 12/29/2003)
   m_visibleItem = it_v;
 
-  TQTimer::singleShot(100, this, TQT_SLOT(slotShowSelected()));
+  TQTimer::singleShot(100, this, TQ_SLOT(slotShowSelected()));
 }
 
 void KMyMoneySelector::slotShowSelected(void)
