@@ -15,10 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <typeinfo>
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqstring.h>
 #include <tqtimer.h>
@@ -28,7 +32,7 @@
 #include <tqimage.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdelocale.h>
 #include <tdeglobal.h>
@@ -184,7 +188,7 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
         break;
 
       case EntryOrderSort:
-        rc = qstrcmp(i1->sortEntryOrder(), i2->sortEntryOrder());
+        rc = TQString::compare(i1->sortEntryOrder(), i2->sortEntryOrder());
         break;
 
       case TypeSort:
@@ -214,7 +218,7 @@ bool ItemPtrVector::item_cmp(RegisterItem* i1, RegisterItem* i2)
   }
 
   if(rc == 0) {
-    rc = qstrcmp(i1->sortEntryOrder(), i2->sortEntryOrder());
+    rc = TQString::compare(i1->sortEntryOrder(), i2->sortEntryOrder());
   }
 
   return rc < 0;
@@ -421,7 +425,7 @@ void SimpleDateGroupMarker::paintRegisterCell(TQPainter* painter, int row, int /
     cg.setColor(TQColorGroup::Base, KMyMoneyGlobalSettings::listBGColor());
   TQBrush backgroundBrush(cg.base());
   // backgroundBrush.setStyle(TQt::DiagCrossPattern);
-  backgroundBrush.setStyle(Qt::Dense5Pattern);
+  backgroundBrush.setStyle(TQt::Dense5Pattern);
   backgroundBrush.setColor(KMyMoneyGlobalSettings::listGridColor());
   painter->eraseRect(cellRect);
   painter->fillRect(cellRect, backgroundBrush);
@@ -589,11 +593,11 @@ Register::Register(TQWidget *parent, const char *name ) :
   // never show horizontal scroll bars
   setHScrollBarMode(TQScrollView::AlwaysOff);
 
-  connect(this, TQT_SIGNAL(clicked(int, int, int, const TQPoint&)), this, TQT_SLOT(selectItem(int, int, int, const TQPoint&)));
-  connect(this, TQT_SIGNAL(doubleClicked(int, int, int, const TQPoint&)), this, TQT_SLOT(slotDoubleClicked(int, int, int, const TQPoint&)));
+  connect(this, TQ_SIGNAL(clicked(int, int, int, const TQPoint&)), this, TQ_SLOT(selectItem(int, int, int, const TQPoint&)));
+  connect(this, TQ_SIGNAL(doubleClicked(int, int, int, const TQPoint&)), this, TQ_SLOT(slotDoubleClicked(int, int, int, const TQPoint&)));
 
   // double clicking the header turns on auto column sizing
-  connect(horizontalHeader(), TQT_SIGNAL(sectionSizeChanged(int)), this, TQT_SLOT(slotAutoColumnSizing(int)));
+  connect(horizontalHeader(), TQ_SIGNAL(sectionSizeChanged(int)), this, TQ_SLOT(slotAutoColumnSizing(int)));
 
   //DND
   setAcceptDrops(true);
@@ -633,7 +637,7 @@ void Register::dropEvent(TQDropEvent* event)
       tqDebug("Drop was ok");
       KURL::List urls;
       KURLDrag::decode(event, urls);
-      tqDebug("List is '%s'", urls.toStringList().join(";").data());
+      tqDebug(TQString("List is '%s'").arg(urls.toStringList().join(";")));
       event->accept();
     }
   }
@@ -667,7 +671,7 @@ void Register::slotAutoColumnSizing(int section)
       }
       size += TQString("%1").arg((columnWidth(i) * 100) / w);
     }
-    tqDebug("size = %s", size.data());
+    tqDebug(TQString("size = %1").arg(size));
     m_account.setValue("kmm-ledger-column-width", size);
   }
 #endif
@@ -675,21 +679,21 @@ void Register::slotAutoColumnSizing(int section)
 
 bool Register::eventFilter(TQObject* o, TQEvent* e)
 {
-  if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(horizontalHeader()) && e->type() == TQEvent::MouseButtonPress) {
+  if(o == horizontalHeader() && e->type() == TQEvent::MouseButtonPress) {
     TQMouseEvent *me = dynamic_cast<TQMouseEvent*>(e);
-    if(me->button() == Qt::RightButton) {
+    if(me->button() == TQt::RightButton) {
       emit headerClicked();
     }
     // eat up left mouse button press for now
     return true;
 
-  } else if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(horizontalHeader()) && e->type() == TQEvent::Paint) {
+  } else if(o == horizontalHeader() && e->type() == TQEvent::Paint) {
     // always show the header in bold (to suppress cell selection)
     TQFont f(horizontalHeader()->font());
     f.setBold(true);
     horizontalHeader()->setFont(f);
 
-  } else if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) && e->type() == TQEvent::KeyPress) {
+  } else if(o == this && e->type() == TQEvent::KeyPress) {
     TQKeyEvent* ke = dynamic_cast<TQKeyEvent*>(e);
     if(ke->key() == TQt::Key_Menu) {
       emit openContextMenu();
@@ -1163,7 +1167,7 @@ void Register::updateRegister(bool forceUpdateRowHeight)
 
     // force resizeing of the columns if necessary
     if(m_needInitialColumnResize) {
-      TQTimer::singleShot(0, this, TQT_SLOT(resize()));
+      TQTimer::singleShot(0, this, TQ_SLOT(resize()));
       m_needInitialColumnResize = false;
     } else {
       updateContents();
@@ -1171,7 +1175,7 @@ void Register::updateRegister(bool forceUpdateRowHeight)
       // if the number of rows changed, we might need to resize the register
       // to make sure we reflect the current visibility of the scrollbars.
       if(needUpdateHeaders)
-        TQTimer::singleShot(0, this, TQT_SLOT(resize()));
+        TQTimer::singleShot(0, this, TQ_SLOT(resize()));
     }
   }
   ::timetrace("Done updateing register");
@@ -1586,12 +1590,12 @@ void Register::selectItem(int row, int col, int button, const TQPoint& /* mouseP
     Transaction* t = dynamic_cast<Transaction*>(item);
     if(t) {
       if(!id.isEmpty()) {
-        switch(button & Qt::MouseButtonMask) {
-          case Qt::RightButton:
+        switch(button & TQt::MouseButtonMask) {
+          case TQt::RightButton:
             emit openContextMenu();
             break;
 
-          case Qt::LeftButton:
+          case TQt::LeftButton:
             if(t && col == ReconcileFlagColumn && selectedItemsCount() == 1 && !t->isScheduled())
               emit reconcileStateColumnClicked(t);
             break;
@@ -1655,7 +1659,7 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
   // kdDebug(2) << "Register::selectItem(" << item << "): type is " << typeid(*item).name() << endl;
 
   TQt::ButtonState buttonState = m_buttonState;
-  m_buttonState = Qt::NoButton;
+  m_buttonState = TQt::NoButton;
 
   if(m_selectionMode == NoSelection)
     return;
@@ -1671,7 +1675,7 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
         sameEntryType = false;
     }
 
-    if(buttonState & Qt::LeftButton) {
+    if(buttonState & TQt::LeftButton) {
       if(!(buttonState & (TQt::ShiftButton | TQt::ControlButton))) {
         if((cnt != 1) || ((cnt == 1) && !item->isSelected())) {
           emit aboutToSelectItem(item, okToSelect);
@@ -1718,7 +1722,7 @@ void Register::selectItem(RegisterItem* item, bool dontChangeSelections)
             break;
         }
       }
-    } else if(buttonState & Qt::RightButton) {
+    } else if(buttonState & TQt::RightButton) {
       // if the right button is pressed then only change the
       // selection if none of the Shift/Ctrl button is pressed and
       // one of the following conditions is true:
@@ -1766,7 +1770,7 @@ void Register::ensureItemVisible(RegisterItem* item)
     return;
 
   m_ensureVisibleItem = item;
-  TQTimer::singleShot(0, this, TQT_SLOT(slotEnsureItemVisible()));
+  TQTimer::singleShot(0, this, TQ_SLOT(slotEnsureItemVisible()));
 }
 
 void Register::slotDoubleClicked(int row, int, int, const TQPoint&)
@@ -1786,7 +1790,7 @@ void Register::slotDoubleClicked(int row, int, int, const TQPoint&)
       if(m_focusItem->isSelected()) {
         // don't emit the signal right away but wait until
         // we come back to the TQt main loop
-        TQTimer::singleShot(0, this, TQT_SIGNAL(editTransaction()));
+        TQTimer::singleShot(0, this, TQ_SIGNAL(editTransaction()));
       }
     }
   }
@@ -1849,7 +1853,7 @@ void Register::slotEnsureItemVisible(void)
 TransactionSortField KMyMoneyRegister::textToSortOrder(const TQString& text)
 {
   for(int idx = 1; idx < static_cast<int>(MaxSortFields); ++idx) {
-    if(text == i18n(sortOrderText[idx])) {
+    if(text == i18n(sortOrderText[idx].utf8())) {
       return static_cast<TransactionSortField>(idx);
     }
   }
@@ -1860,7 +1864,7 @@ const TQString KMyMoneyRegister::sortOrderToText(TransactionSortField idx)
 {
   if(idx < PostDateSort || idx >= MaxSortFields)
     idx = UnknownSort;
-  return i18n(sortOrderText[idx]);
+  return i18n(sortOrderText[idx].utf8());
 }
 
 TQString Register::text(int /*row*/, int /*col*/) const
@@ -1885,7 +1889,7 @@ TQWidget* Register::cellWidget(int row, int col) const
     return 0;
 
   TQWidget* w = 0;
-  TQPair<int, int> idx = tqMakePair(row, col);
+  TQPair<int, int> idx = qMakePair(row, col);
   TQMap<TQPair<int, int>, TQWidget*>::const_iterator it_w;
 
   it_w = m_cellWidgets.find(idx);
@@ -1901,7 +1905,7 @@ void Register::insertWidget(int row, int col, TQWidget* w)
     return;
   }
 
-  TQPair<int, int> idx = tqMakePair(row, col);
+  TQPair<int, int> idx = qMakePair(row, col);
   m_cellWidgets[idx] = w;
 }
 
@@ -1912,7 +1916,7 @@ void Register::clearCellWidget(int row, int col)
     return;
   }
 
-  TQPair<int, int> idx = tqMakePair(row, col);
+  TQPair<int, int> idx = qMakePair(row, col);
   TQMap<TQPair<int, int>, TQWidget*>::iterator it_w;
 
   it_w = m_cellWidgets.find(idx);
@@ -1985,7 +1989,7 @@ void Register::slotToggleErronousTransactions(void)
   }
 
   // restart timer
-  TQTimer::singleShot(500, this, TQT_SLOT(slotToggleErronousTransactions()));
+  TQTimer::singleShot(500, this, TQ_SLOT(slotToggleErronousTransactions()));
 }
 
 RegisterItem* Register::itemById(const TQString& id) const
@@ -2177,7 +2181,7 @@ void Register::keyPressEvent(TQKeyEvent* ev)
         // get the state out of the event ...
         m_buttonState = ev->state();
         // ... and pretend that we have pressed the left mouse button ;)
-        m_buttonState = static_cast<TQt::ButtonState>(m_buttonState | Qt::LeftButton);
+        m_buttonState = static_cast<TQt::ButtonState>(m_buttonState | TQt::LeftButton);
         selectItem(m_focusItem);
       }
       break;
@@ -2291,7 +2295,7 @@ void Register::addGroupMarkers(void)
           if(m_account.accountGroup() == MyMoneyAccount::Liability)
             balance = -balance;
           TQString txt = i18n("Online Statement Balance: %1").arg(balance.formatMoney(m_account.fraction()));
-          new KMyMoneyRegister::StatementGroupMarker(this, KMyMoneyRegister::Deposit, TQDate::fromString(m_account.value("lastImportedTransactionDate"), Qt::ISODate), txt);
+          new KMyMoneyRegister::StatementGroupMarker(this, KMyMoneyRegister::Deposit, TQDate::fromString(m_account.value("lastImportedTransactionDate"), TQt::ISODate), txt);
         }
 
         new KMyMoneyRegister::FancyDateGroupMarker(this, thisYear, i18n("This year"));
