@@ -20,7 +20,7 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqfile.h>
 #include <tqdir.h>
@@ -30,7 +30,7 @@
 
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeapplication.h>
 #include <tdelocale.h>
@@ -178,7 +178,7 @@ bool KGPGFile::open(int mode, const TQString& cmdArgs, bool skipPasswd)
     args = TQStringList::split(" ", cmdArgs);
   }
 
-  TQCString pwd;
+  TQString pwd;
   if(isReadable() && useOwnPassphrase && !skipPasswd) {
     KPasswordDialog dlg(KPasswordDialog::Password,false,0);
     dlg.setPrompt(i18n("Enter passphrase"));
@@ -186,7 +186,7 @@ bool KGPGFile::open(int mode, const TQString& cmdArgs, bool skipPasswd)
     dlg.adjustSize();
     if (dlg.exec() == TQDialog::Rejected)
       return false;
-    pwd = TQCString(dlg.password());
+    pwd = dlg.password();
   }
 
   // tqDebug("starting GPG process");
@@ -207,8 +207,9 @@ bool KGPGFile::open(int mode, const TQString& cmdArgs, bool skipPasswd)
   }
 
   if(isReadable() && useOwnPassphrase && !skipPasswd) {
-    // tqDebug("Passphrase is '%s'", pwd.data());
-    if(_writeBlock(pwd.data(), pwd.length()) == -1) {
+  	TQCString pwd2 = pwd.local8Bit();  // Local 8 bit length can be different from TQString length
+    // tqDebug("Passphrase is '%s'", pwd2.data());
+    if(_writeBlock(pwd2.data(), pwd2.length()) == -1) {
       // tqDebug("Sending passphrase failed");
       return false;
     }
@@ -231,17 +232,17 @@ bool KGPGFile::startProcess(const TQStringList& args)
   // TQString arglist = args.join(":");
   // tqDebug("gpg '%s'", arglist.data());
 
-  connect(m_process, TQT_SIGNAL(processExited(TDEProcess *)),
-          this, TQT_SLOT(slotGPGExited(TDEProcess *)));
+  connect(m_process, TQ_SIGNAL(processExited(TDEProcess *)),
+          this, TQ_SLOT(slotGPGExited(TDEProcess *)));
 
-  connect(m_process, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
-          this, TQT_SLOT(slotDataFromGPG(TDEProcess*, char*, int)));
+  connect(m_process, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
+          this, TQ_SLOT(slotDataFromGPG(TDEProcess*, char*, int)));
 
-  connect(m_process, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)),
-          this, TQT_SLOT(slotErrorFromGPG(TDEProcess*, char*, int)));
+  connect(m_process, TQ_SIGNAL(receivedStderr(TDEProcess*, char*, int)),
+          this, TQ_SLOT(slotErrorFromGPG(TDEProcess*, char*, int)));
 
-  connect(m_process, TQT_SIGNAL(wroteStdin(TDEProcess *)),
-          this, TQT_SLOT(slotSendDataToGPG(TDEProcess *)));
+  connect(m_process, TQ_SIGNAL(wroteStdin(TDEProcess *)),
+          this, TQ_SLOT(slotSendDataToGPG(TDEProcess *)));
 
   if(!m_process->start(TDEProcess::NotifyOnExit, (TDEProcess::Communication)(TDEProcess::Stdin|TDEProcess::Stdout|TDEProcess::Stderr))) {
     // tqDebug("m_process->start failed");
@@ -564,7 +565,7 @@ void KGPGFile::publicKeyList(TQStringList& list, const TQString& pattern)
     TQStringList fields = TQStringList::split(":", (*it), true);
     TQString val;
     if(fields[0] == "pub") {
-      TQDate expiration = TQDate::fromString(fields[6], Qt::ISODate);
+      TQDate expiration = TQDate::fromString(fields[6], TQt::ISODate);
       if(expiration >  TQDate::currentDate()) {
         currentKey = fields[4];
         val = TQString("%1:%2").arg(currentKey).arg(fields[9]);
